==> isqlite-0.9.1.tar.gz: isqlite-0.9.1/isqlite/__init__.py <==
import datetime
import decimal
import sqlite3

# Re-export some names from sqliteparser.
from sqliteparser.ast import OnConflict, OnDelete, OnUpdate

from .core import (
    AddColumnMigration,
    AlterColumnMigration,
    AutoTable,
    BooleanColumn,
    ColumnDoesNotExistError,
    CreateTableMigration,
    Database,
    DateColumn,
    DecimalColumn,
    DropColumnMigration,
    DropTableMigration,
    ForeignKeyColumn,
    IntegerColumn,
    ISqliteApiError,
    ISqliteError,
    PrimaryKeyColumn,
    PrintDebugger,
    ReorderColumnsMigration,
    Table,
    TableDoesNotExistError,
    TextColumn,
    TimeColumn,
    TimestampColumn,
)


def sqlite3_convert_boolean(b):
    return b != b"0"


def sqlite3_convert_decimal(b):
    return decimal.Decimal(b.decode("utf8"))


def sqlite3_adapt_decimal(d):
    return str(d)


def sqlite3_convert_time(b):
    parts = b.decode("utf8").split(":", maxsplit=2)
    if len(parts) == 3:
        hour = int(parts[0])
        minute = int(parts[1])
        second = int(parts[2])
    else:
        hour = int(parts[0])
        minute = int(parts[1])
        second = 0

    return datetime.time(hour, minute, second)


def sqlite3_adapt_time(t):
    return str(t)


sqlite3.register_converter("BOOLEAN", sqlite3_convert_boolean)
sqlite3.register_converter("DECIMAL", sqlite3_convert_decimal)
sqlite3.register_adapter(decimal.Decimal, sqlite3_adapt_decimal)
sqlite3.register_converter("TIME", sqlite3_convert_time)
sqlite3.register_adapter(datetime.time, sqlite3_adapt_time)

del sqlite3_convert_boolean
del sqlite3_convert_decimal
del sqlite3_adapt_decimal
del sqlite3_convert_time
del sqlite3_adapt_time

==> isqlite-1.5.1.tar.gz: isqlite-1.5.1/isqlite/__init__.py <==
import datetime
import decimal
import sqlite3
import warnings

# Re-export some names from sqliteparser.
from sqliteparser.ast import OnConflict, OnDelete, OnUpdate

from . import columns, migrations
from .database import Database
from .exceptions import (
    ColumnDoesNotExistError,
    ISqliteApiError,
    ISqliteError,
    TableDoesNotExistError,
)
from .schema import AutoTable, Schema, Table

warnings.warn(
    "The isqlite library is deprecated and no longer maintained as of February 2023.",
    DeprecationWarning,
)


def sqlite3_convert_boolean(b):
    return b != b"0"


def sqlite3_convert_decimal(b):
    return decimal.Decimal(b.decode("utf8"))


def sqlite3_adapt_decimal(d):
    return str(d)


def sqlite3_convert_time(b):
    parts = b.decode("utf8").split(":", maxsplit=2)
    if len(parts) == 3:
        hour = int(parts[0])
        minute = int(parts[1])
        second = int(parts[2])
    else:
        hour = int(parts[0])
        minute = int(parts[1])
        second = 0

    return datetime.time(hour, minute, second)


def sqlite3_adapt_time(t):
    return str(t)


sqlite3.register_converter("BOOLEAN", sqlite3_convert_boolean)
sqlite3.register_converter("DECIMAL", sqlite3_convert_decimal)
sqlite3.register_adapter(decimal.Decimal, sqlite3_adapt_decimal)
sqlite3.register_converter("TIME", sqlite3_convert_time)
sqlite3.register_adapter(datetime.time, sqlite3_adapt_time)

del sqlite3_convert_boolean
del sqlite3_convert_decimal
del sqlite3_adapt_decimal
del sqlite3_convert_time
del sqlite3_adapt_time
